function prolozeni_bodu_6_vstup(x,y,n)
% proložení bodù se souøadnicemi x,y polynomem n-tého stupnì
    % hlavièka funkce je ve tvaru function nazev(vstup)
    % hlavièka zajiš�uje pøenos dat z a do funkce
    % x - x-ové souøadnice bodù (vektor x)
    % y - y-ové souøadnice bodù (vektor y)
    % n - stupen polynomu, kterym budou body prolozeny
xp=[min(x):((max(x)-min(x))/100):max(x)];   % body, ve kterých bude poèítána aproximace
    % jemnìjší dìlení osy x pro zobrazení køivky
    % od minima z vektoru x do maxima z vektoru x s krokem vypoctenym (max(x)-min(x))/100
yn=polyval(polyfit(x,y,n),xp); 	% body získané polynomiální interpolací
                                % polynom n-tého stupnì
plot(x,y,'*',xp,yn,':m','LineWidth',3) 
    % vykresleni dvourozmìrného grafu
    % body - zobrazeny jako hvezdicky 
	% proložení polynomem n-tého stupnì - zobrazeno fialovì (magenta)
legend('body','polynom n-teho st.')
    % legenda ke grafu